AnimStack

Struct AnimStack 

pub struct AnimStack {
    animations: Vec<AnimationCell>,
    duration_secs: f64,
}
Dynamic overlay animation container.

Unlike AnimSequence, every pushed animation keeps its own local start time and the stack duration is the maximum child extent.

Fields

animations: Vec<AnimationCell>duration_secs: f64

Implementations

Source

impl AnimStack

pub fn new() -> Self

Create an empty dynamic stack.

fn eval_at_sec_into(&self, target_sec: f64, output: &mut Vec<DynItem>)

pub fn push<A: Animation + 'static>(&mut self, animation: A) -> &mut Self

Add an animation without advancing the other children.

pub fn extend(&mut self, stack: AnimStack) -> &mut Self

Add all direct child animations from another dynamic stack.

pub fn duration_secs(&self) -> f64

Current maximum child extent.

pub fn built_animations(&self) -> &[AnimationCell]

Borrow the direct child animations in local stack coordinates.

pub fn into_built_animations(self) -> Vec<AnimationCell>

Consume this stack into its direct child animations.