pub struct AnimStack {
animations: Vec<AnimationCell>,
duration_secs: f64,
}Expand description
Dynamic overlay animation container.
Unlike AnimSequence, every pushed animation keeps its own local start
time and the stack duration is the maximum child extent.
Fields
animations: Vec<AnimationCell>duration_secs: f64Implementations
Sourceimpl AnimStack
impl AnimStack
fn eval_at_sec_into(&self, target_sec: f64, output: &mut Vec<DynItem>)
Sourcepub fn push<A: Animation + 'static>(&mut self, animation: A) -> &mut Self
pub fn push<A: Animation + 'static>(&mut self, animation: A) -> &mut Self
Add an animation without advancing the other children.
Sourcepub fn extend(&mut self, stack: AnimStack) -> &mut Self
pub fn extend(&mut self, stack: AnimStack) -> &mut Self
Add all direct child animations from another dynamic stack.
Sourcepub fn duration_secs(&self) -> f64
pub fn duration_secs(&self) -> f64
Current maximum child extent.
Sourcepub fn built_animations(&self) -> &[AnimationCell]
pub fn built_animations(&self) -> &[AnimationCell]
Borrow the direct child animations in local stack coordinates.
Sourcepub fn into_built_animations(self) -> Vec<AnimationCell>
pub fn into_built_animations(self) -> Vec<AnimationCell>
Consume this stack into its direct child animations.