AnimationCell

Struct AnimationCell 

pub struct AnimationCell<T> {
    inner: Box<dyn Eval<T>>,
    pub info: AnimationInfo,
    anim_name: String,
}
A cell of an animation

Fields

inner: Box<dyn Eval<T>>info: AnimationInfo

The animation info

anim_name: String

Implementations

Source

impl<T> AnimationCell<T>

pub fn at(self, at_sec: f64) -> Self

A builder func to modify AnimationInfo::start_sec

pub fn with_rate_func(self, rate_func: fn(f64) -> f64) -> Self

A builder func to modify AnimationInfo::rate_func

pub fn with_duration(self, duration_secs: f64) -> Self

A builder func to modify AnimationInfo::duration_secs

pub fn with_enabled(self, enabled: bool) -> Self

A builder func to modify AnimationInfo::enabled

pub fn apply_to(self, item: &mut T) -> Self

Apply the animation to the item and return the animation itself

pub fn apply_alpha_to(self, item: &mut T, alpha: f64) -> Self

Apply the animation to the item at the given alpha and return the animation itself