pub struct AnimationCell<T> {
inner: Box<dyn Eval<T>>,
pub info: AnimationInfo,
anim_name: String,
}Expand description
A cell of an animation
Fields
inner: Box<dyn Eval<T>>info: AnimationInfoThe animation info
anim_name: StringImplementations
Sourceimpl<T> AnimationCell<T>
impl<T> AnimationCell<T>
Sourcepub fn at(self, at_sec: f64) -> Self
pub fn at(self, at_sec: f64) -> Self
A builder func to modify AnimationInfo::start_sec
Sourcepub fn with_rate_func(self, rate_func: fn(f64) -> f64) -> Self
pub fn with_rate_func(self, rate_func: fn(f64) -> f64) -> Self
A builder func to modify AnimationInfo::rate_func
Sourcepub fn with_duration(self, duration_secs: f64) -> Self
pub fn with_duration(self, duration_secs: f64) -> Self
A builder func to modify AnimationInfo::duration_secs
Sourcepub fn with_enabled(self, enabled: bool) -> Self
pub fn with_enabled(self, enabled: bool) -> Self
A builder func to modify AnimationInfo::enabled
Sourcepub fn apply_to(self, item: &mut T) -> Self
pub fn apply_to(self, item: &mut T) -> Self
Apply the animation to the item and return the animation itself
Sourcepub fn apply_alpha_to(self, item: &mut T, alpha: f64) -> Self
pub fn apply_alpha_to(self, item: &mut T, alpha: f64) -> Self
Apply the animation to the item at the given alpha and return the animation itself